Struct substrate_api_client::extrinsic::xt_primitives::GenericExtra [−][src]
pub struct GenericExtra(_, _, _);
Simple generic extra mirroring the SignedExtra currently used in extrinsics. Does not implement the SignedExtension trait. It simply encodes to the same bytes as the real SignedExtra. The Order is (CheckVersion, CheckGenesis, Check::Era, CheckNonce, CheckWeight, transactionPayment::ChargeTransactionPayment). This can be locked up in the System module. Fields that are merely PhantomData are not encoded and are therefore omitted here.
Implementations